#include <cstdio>
#include <unistd.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <cstdint>
#include <cstring>
#include <algorithm>

class RC4 {
	uint8_t state[256];
	int i;
	int j;
public:
	RC4(const uint8_t key[], size_t len) {
		for(i = 0; i < 256; ++i) {
			state[i] = i;
		}

		j = 0;
		for(i = 0; i < 256; ++i) {
			j = (j + state[i] + key[i % len]) % 256;
			std::swap(state[i], state[j]);
		}
		i = j = 0;
	}
	uint8_t next() {
		i = (i + 1) % 256;
		j = (j + state[i]) % 256;
		std::swap(state[i], state[j]);
		return state[(state[i] + state[j]) % 256];
	}
};

int main() {
	uint8_t key[6];
	int fd = open("/dev/urandom", O_RDONLY);
	int counts[256];
	memset(counts, 0, sizeof counts);

	for(int i = 0; i < 10000; ++i) {
		//generate a new key
		if(read(fd, key, sizeof key) != sizeof key) exit(1);

		//seed prg
		RC4 prg(key, sizeof key);
		prg.next();

		//update statistics for second output byte
		++counts[prg.next()];
	}
	//second output byte is biased towards 0
	for(int i = 0; i < 256; ++i) {
		printf("%f\n", counts[i]/10000.0);
	}
	return 0;
}
